@@ -1,33 +1,11 @@
-
 """
-File:
-    yclip.py
-
-Description:
-    Clip data and replace values with flag.
-
-Parameters:
-    names: str/list of str
-        List of pytplot names.
-    ymin:
-        Minimum value to clip
-    ymax:
-        Maximum value to clip
-    flag:
-        Values outside (ymin, ymax) are replaced with flag.
-        Default is float('nan').
-    new_names: str/list of str
-        List of new_names for pytplot variables.
-        If not given, then a suffix is applied.
-    suffix:
-        A suffix to apply. Default is '-clip'.
-    overwrite:
-        Replace the existing tplot name.
+Clip data and replace values with flag.
 
 Notes:
-    Allowed wildcards are ? for a single character, * from multiple characters.
-    Similar to tclip in IDL SPEDAS.
-    This function clips y-axis data. To clip time-axis, use time_clip.
+Allowed wildcards are ? for a single character, * from multiple characters.
+Similar to tclip.pro in IDL SPEDAS.
+This function clips y-axis data. To clip time-axis, use time_clip.
+
 """
 
 import pyspedas
@@ -37,7 +15,33 @@ import numpy as np
 
 def yclip(names, ymin, ymax, flag=None, new_names=None, suffix=None,
           overwrite=None):
+    """
+    Clip data values.
 
+    Parameters
+    ----------
+    names: str/list of str
+        List of pytplot names.
+    ymin: float
+        Minimum value to clip.
+    ymax: float
+        Maximum value to clip.
+    flag: float, optional
+        Values outside (ymin, ymax) are replaced with flag.
+        Default is float('nan').
+    new_names: str/list of str, optional
+        List of new_names for pytplot variables.
+        If not given, then a suffix is applied.
+    suffix: str, optional
+        A suffix to apply. Default is '-clip'.
+    overwrite: bool, optional
+        Replace the existing tplot name.
+
+    Returns
+    -------
+    None.
+
+    """
     old_names = pyspedas.tnames(names)
 
     if len(old_names) < 1:
