@@ -25,6 +25,7 @@ from .feeps.mms_feeps_spin_avg import mms_feeps_spin_avg
 from .eis.mms_eis_omni import mms_eis_omni
 from .eis.mms_eis_spin_avg import mms_eis_spin_avg
 from .eis.mms_eis_set_metadata import mms_eis_set_metadata
+from pyspedas.mms.mec_ascii.mms_get_state_data import mms_get_state_data
 from .mms_config import CONFIG
 
 from pyspedas import tnames
@@ -50,9 +51,46 @@ def print_vars(func):
     wrapper.__doc__ = func.__doc__
     return wrapper
 
+@print_vars
+def mms_load_state(trange=['2015-10-16', '2015-10-17'], probe='1', level='def',
+    datatypes=['pos', 'vel'], no_update=False, pred_or_def=True, suffix=''):
+    """
+    This function loads the state (ephemeris and attitude) data from the ASCII files 
+    into tplot variables
+    
+    Parameters:
+        trange : list of str
+            time range of interest [starttime, endtime] with the format 
+            'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
+            ['YYYY-MM-DD/hh:mm:ss','YYYY-MM-DD/hh:mm:ss']
+
+        probe : str or list of str
+            list of probes, valid values for MMS probes are ['1','2','3','4']. 
+
+        level : str
+            indicates level of data (options: 'def' (definitive), 'pred' (predicted); default: def)
+
+        datatypes : str or list of str
+            no datatype for state data (options: 'pos', 'vel', 'spinras', 'spindec')
+
+        suffix: str
+            The tplot variable names will be given this suffix.  By default, 
+            no suffix is added.
+
+        no_update: bool
+            Set this flag to preserve the original data. if not set and newer 
+            data is found the existing data will be overwritten
+
+    Returns:
+        List of tplot variables created.
+
+    """
+    return mms_get_state_data(trange=trange, probe=probe, level=level, datatypes=datatypes,
+        no_download=no_update, pred_or_def=pred_or_def, suffix=suffix)
+
 @print_vars
 def mms_load_fgm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy',
-    level='l2', instrument='fgm', datatype='', varformat=None, suffix='',
+    level='l2', instrument='fgm', datatype='', varformat=None, varnames=[], suffix='',
     keep_flagged=False, get_support_data=True, time_clip=False, no_update=False,
     available=False, notplot=False, latest_version=False, major_version=False, 
     min_version=None, cdf_version=None, spdf=False, always_prompt=False):
@@ -90,6 +128,10 @@ def mms_load_fgm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -141,7 +183,7 @@ def mms_load_fgm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
         varformat_fetch = varformat
 
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument=instrument,
-            datatype=datatype, varformat=varformat_fetch, suffix=suffix, get_support_data=get_support_data,
+            datatype=datatype, varformat=varformat_fetch, varnames=varnames, suffix=suffix, get_support_data=get_support_data,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, major_version=major_version, 
             min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
     
@@ -170,7 +212,7 @@ def mms_load_fgm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 @print_vars
 def mms_load_hpca(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
     level='l2', datatype='moments', get_support_data=None, time_clip=False, no_update=False,
-    varformat=None, suffix='', center_measurement=False, available=False, notplot=False, 
+    varformat=None, varnames=[], suffix='', center_measurement=False, available=False, notplot=False, 
     latest_version=False, major_version=False, min_version=None, cdf_version=None, spdf=False,
     always_prompt=False):
     """
@@ -204,6 +246,10 @@ def mms_load_hpca(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srv
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         time_clip: bool
             Data will be clipped to the exact trange specified by the trange keyword.
 
@@ -257,7 +303,7 @@ def mms_load_hpca(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srv
         get_support_data = True
 
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='hpca',
-            datatype=datatype, varformat=varformat, suffix=suffix, get_support_data=get_support_data,
+            datatype=datatype, varformat=varformat, varnames=varnames, suffix=suffix, get_support_data=get_support_data,
             time_clip=time_clip, no_update=no_update, center_measurement=center_measurement, available=available, 
             latest_version=latest_version, major_version=major_version, min_version=min_version, cdf_version=cdf_version,
             spdf=spdf, always_prompt=always_prompt)
@@ -270,7 +316,7 @@ def mms_load_hpca(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srv
 
 @print_vars
 def mms_load_fpi(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast',
-    level='l2', datatype=['des-moms', 'dis-moms'], varformat=None, suffix='',
+    level='l2', datatype=['des-moms', 'dis-moms'], varformat=None, varnames=[], suffix='',
     get_support_data=False, time_clip=False, no_update=False, center_measurement=False,
     available=False, notplot=False, latest_version=False, major_version=False, 
     min_version=None, cdf_version=None, spdf=False, always_prompt=False):
@@ -310,6 +356,10 @@ def mms_load_fpi(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -357,7 +407,7 @@ def mms_load_fpi(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
     """
 
     tvars = mms_load_data(trange=trange, probe=probe, data_rate=data_rate, level=level, instrument='fpi',
-            datatype=datatype, varformat=varformat, suffix=suffix, get_support_data=get_support_data,
+            datatype=datatype, varformat=varformat, varnames=varnames, suffix=suffix, get_support_data=get_support_data,
             time_clip=time_clip, no_update=no_update, center_measurement=center_measurement, available=available, 
             notplot=notplot, latest_version=latest_version, major_version=major_version, min_version=min_version, 
             cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
@@ -371,8 +421,8 @@ def mms_load_fpi(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
 
 @print_vars
 def mms_load_scm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
-    level='l2', datatype='', varformat=None, suffix='', get_support_data=False,
-    time_clip=False, no_update=False, available=False, notplot=False, latest_version=False, 
+    level='l2', datatype='', varformat=None, varnames=[], suffix='', get_support_data=False,
+    time_clip=True, no_update=False, available=False, notplot=False, latest_version=False, 
     major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads SCM data into tplot variables
@@ -409,6 +459,10 @@ def mms_load_scm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -470,7 +524,7 @@ def mms_load_scm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
             datatype.remove('')
 
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='scm',
-            datatype=datatype, varformat=varformat, suffix=suffix, get_support_data=get_support_data,
+            datatype=datatype, varformat=varformat, varnames=varnames, suffix=suffix, get_support_data=get_support_data,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
             major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, 
             always_prompt=always_prompt)
@@ -502,7 +556,7 @@ def mms_load_scm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 
 @print_vars
 def mms_load_mec(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
-    level='l2', datatype='ephts04d', varformat=None, suffix='', get_support_data=False,
+    level='l2', datatype='ephts04d', varformat=None, varnames=[], suffix='', get_support_data=False,
     time_clip=False, no_update=False, available=False, notplot=False, latest_version=False, 
     major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
@@ -539,6 +593,10 @@ def mms_load_mec(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -580,7 +638,7 @@ def mms_load_mec(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 
     """
     tvars = mms_load_data(trange=trange, probe=probe, data_rate=data_rate, level=level, instrument='mec',
-            datatype=datatype, get_support_data=get_support_data, varformat=varformat, suffix=suffix,
+            datatype=datatype, get_support_data=get_support_data, varformat=varformat, varnames=varnames, suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, notplot=notplot, 
             latest_version=latest_version, major_version=major_version, min_version=min_version, 
             cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
@@ -594,7 +652,7 @@ def mms_load_mec(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 
 @print_vars
 def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
-    level='l2', datatype='electron', varformat=None, get_support_data=True, suffix='', time_clip=False,
+    level='l2', datatype='electron', varformat=None, varnames=[], get_support_data=True, suffix='', time_clip=False,
     no_update=False, available=False, notplot=False, no_flatfield_corrections=False, data_units=['count_rate', 'intensity'], 
     latest_version=False, major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
@@ -633,6 +691,10 @@ def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -674,7 +736,7 @@ def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
 
     """
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='feeps',
-            datatype=datatype, varformat=varformat, get_support_data=get_support_data, suffix=suffix,
+            datatype=datatype, varformat=varformat, varnames=varnames, get_support_data=get_support_data, suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
             major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
 
@@ -685,6 +747,7 @@ def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
     data_rates = data_rate if isinstance(data_rate, list) else [data_rate]
     levels = level if isinstance(level, list) else [level]
     datatypes = datatype if isinstance(datatype, list) else [datatype]
+    data_units = data_units if isinstance(data_units, list) else [data_units]
 
     probes = [str(p) for p in probes]
 
@@ -696,7 +759,7 @@ def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
     for probe in probes:
         for datatype in datatypes:
            mms_feeps_remove_bad_data(probe=probe, data_rate=data_rate, datatype =datatype, level=level, suffix=suffix)
-           
+
            for data_unit in data_units:
                eyes = mms_feeps_active_eyes(trange, probe, data_rate, datatype, level)
 
@@ -714,7 +777,7 @@ def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
 
 @print_vars
 def mms_load_eis(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', level='l2', datatype='extof',
-        varformat=None, get_support_data=True, suffix='', time_clip=False, no_update=False,
+        varformat=None, varnames=[], get_support_data=True, suffix='', time_clip=False, no_update=False,
         available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, 
         spdf=False, always_prompt=False):
     """
@@ -751,6 +814,10 @@ def mms_load_eis(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -793,7 +860,7 @@ def mms_load_eis(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
     """
 
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='epd-eis',
-            datatype=datatype, varformat=varformat, get_support_data=get_support_data, prefix='', suffix=suffix,
+            datatype=datatype, varformat=varformat, varnames=varnames, get_support_data=get_support_data, prefix='', suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
             major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
 
@@ -890,7 +957,7 @@ def mms_load_eis(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 
 @print_vars
 def mms_load_edi(trange=['2016-10-16', '2016-10-17'], probe='1', data_rate='srvy', level='l2', datatype='efield',
-        varformat=None, get_support_data=False, suffix='', time_clip=False, no_update=False,
+        varformat=None, varnames=[], get_support_data=False, suffix='', time_clip=False, no_update=False,
         available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, 
         spdf=False, always_prompt=False):
     """
@@ -927,6 +994,10 @@ def mms_load_edi(trange=['2016-10-16', '2016-10-17'], probe='1', data_rate='srvy
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -968,7 +1039,7 @@ def mms_load_edi(trange=['2016-10-16', '2016-10-17'], probe='1', data_rate='srvy
 
     """
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='edi',
-            datatype=datatype, varformat=varformat, get_support_data=get_support_data, suffix=suffix, time_clip=time_clip, 
+            datatype=datatype, varformat=varformat, varnames=varnames, get_support_data=get_support_data, suffix=suffix, time_clip=time_clip, 
             no_update=no_update, available=available, latest_version=latest_version, major_version=major_version, 
             min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
 
@@ -981,7 +1052,7 @@ def mms_load_edi(trange=['2016-10-16', '2016-10-17'], probe='1', data_rate='srvy
 
 @print_vars
 def mms_load_edp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast', level='l2', datatype='dce',
-        varformat=None, get_support_data=False, suffix='', time_clip=False, no_update=False,
+        varformat=None, varnames=[], get_support_data=False, suffix='', time_clip=True, no_update=False,
         available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, 
         spdf=False, always_prompt=False):
     """
@@ -1018,6 +1089,10 @@ def mms_load_edp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -1059,7 +1134,7 @@ def mms_load_edp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
 
     """
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='edp',
-            datatype=datatype, varformat=varformat, get_support_data=get_support_data, suffix=suffix,
+            datatype=datatype, varformat=varformat, varnames=varnames, get_support_data=get_support_data, suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
             major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, 
             always_prompt=always_prompt)
@@ -1073,7 +1148,7 @@ def mms_load_edp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
 
 @print_vars
 def mms_load_dsp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
-    level='l2', datatype='bpsd', varformat=None, suffix='', get_support_data=False,
+    level='l2', datatype='bpsd', varformat=None, varnames=[], suffix='', get_support_data=False,
     time_clip=False, no_update=False, available=False, notplot=False, latest_version=False, 
     major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
@@ -1110,6 +1185,10 @@ def mms_load_dsp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -1151,7 +1230,7 @@ def mms_load_dsp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 
     """
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='dsp',
-            datatype=datatype, varformat=varformat, suffix=suffix, get_support_data=get_support_data, time_clip=time_clip, 
+            datatype=datatype, varformat=varformat, varnames=varnames, suffix=suffix, get_support_data=get_support_data, time_clip=time_clip, 
             no_update=no_update, available=available, latest_version=latest_version, major_version=major_version, 
             min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
     
@@ -1164,7 +1243,7 @@ def mms_load_dsp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 
 @print_vars
 def mms_load_aspoc(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
-    level='l2', datatype='', varformat=None, get_support_data=False, suffix='', time_clip=False, no_update=False,
+    level='l2', datatype='', varformat=None, varnames=[], get_support_data=False, suffix='', time_clip=False, no_update=False,
     available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, 
     spdf=False, always_prompt=False):
     """
@@ -1201,6 +1280,10 @@ def mms_load_aspoc(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -1241,8 +1324,13 @@ def mms_load_aspoc(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
         List of tplot variables created.
 
     """
+
+    if suffix == '':
+        suffix = '_' + level
+    else:
+        suffix = '_' + level + suffix
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='aspoc',
-            datatype=datatype, varformat=varformat, get_support_data=get_support_data, suffix=suffix,
+            datatype=datatype, varformat=varformat, varnames=varnames, get_support_data=get_support_data, suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
             major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, 
             always_prompt=always_prompt)
@@ -1251,7 +1339,7 @@ def mms_load_aspoc(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
 @print_vars
 def mms_load_fsm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='brst', 
     level='l3', datatype='8khz', get_support_data=False, time_clip=False, no_update=False, 
-    available=False, varformat=None, notplot=False, suffix='', latest_version=False, 
+    available=False, varformat=None, varnames=[], notplot=False, suffix='', latest_version=False, 
     major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads FSM data into tplot variables
@@ -1282,6 +1370,14 @@ def mms_load_fsm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='brst
         time_clip: bool
             Data will be clipped to the exact trange specified by the trange keyword.
 
+        varformat: str
+            The file variable formats to load into tplot.  Wildcard character
+            "*" is accepted.  By default, all variables are loaded in.
+
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
             no suffix is added.
@@ -1324,7 +1420,7 @@ def mms_load_fsm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='brst
     """
     tvars = mms_load_data(trange=trange, notplot=notplot, varformat=varformat, probe=probe, data_rate=data_rate, 
         level=level, instrument='fsm', datatype=datatype, get_support_data=get_support_data, time_clip=time_clip, 
-        no_update=no_update, available=available, suffix=suffix, latest_version=latest_version, 
+        no_update=no_update, available=available, suffix=suffix, latest_version=latest_version, varnames=varnames,
         major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
     return tvars
 
@@ -1341,6 +1437,10 @@ def mms_load_fsm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='brst
             >>> fgm_data = pyspedas.mms.fgm(...)
 '''
 
+@wraps(mms_load_state)
+def state(*args, **kwargs):
+    return mms_load_state(*args, **kwargs)
+
 @wraps(mms_load_fgm)
 def fgm(*args, **kwargs):
     return mms_load_fgm(*args, **kwargs)
